@@ -325,7 +325,7 @@ sub add_specials
             |
            \'((?:\\.|[^'])*)\'
             |
-           (\S+))/ogx)
+           (\S+))/ogx)  #"
         {
             $self->{$1} = $2 || $3 || $4;
         }
